summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/toolbar_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/views/toolbar_view.h')
-rw-r--r--chrome/browser/views/toolbar_view.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/views/toolbar_view.h b/chrome/browser/views/toolbar_view.h
index 169448b..efd9d2c 100644
--- a/chrome/browser/views/toolbar_view.h
+++ b/chrome/browser/views/toolbar_view.h
@@ -227,8 +227,8 @@ class ToolbarView : public views::View,
// Current tab we're showing state for.
TabContents* tab_;
- // Profiles menu to populate with profile names.
- views::Menu* profiles_menu_;
+ // Contents of the profiles menu to populate with profile names.
+ scoped_ptr<views::SimpleMenuModel> profiles_menu_contents_;
// Helper class to enumerate profiles information on the file thread.
scoped_refptr<GetProfilesHelper> profiles_helper_;